@@ -1067,11 +1067,8 @@ again:
 					goto end2;
 				}
 
-				/* Disable card detection thread for APG8201 series. */
-				if ((usbDevice[reader_index].ccid.readerID == ACS_APG8201)
-					|| (usbDevice[reader_index].ccid.readerID == ACS_APG8201_B2)
-					|| (usbDevice[reader_index].ccid.readerID == ACS_APG8201Z)
-					|| (usbDevice[reader_index].ccid.readerID == ACS_APG8201Z2))
+				/* Disable card detection thread for APG8201-B2. */
+				if (usbDevice[reader_index].ccid.readerID == ACS_APG8201_B2)
 				{
 					goto end;
 				}
@@ -1770,7 +1767,7 @@ int InterruptRead(int reader_index, int timeout /* in ms */)
 	if (usbDevice[reader_index].multislot_extension != NULL)
 		return Multi_InterruptRead(reader_index, timeout);
 
-	DEBUG_PERIODIC2("before (%d)", reader_index);
+	DEBUG_PERIODIC3("before (%d), timeout: %d ms", reader_index, timeout);
 
 	transfer = libusb_alloc_transfer(0);
 	if (NULL == transfer)
